==> httpcomponents-core-5.0.4-src.tar.gz: httpcore5/src/test/java/org/apache/hc/core5/http/config/TestRegistry.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.hc.core5.http.config;

import org.junit.Assert;
import org.junit.Test;

public class TestRegistry {

    @Test
    public void testCompleted() throws Exception {
        final Registry<String> reg = RegistryBuilder.<String>create().register("Stuff", "Stuff").build();
        Assert.assertEquals("Stuff", reg.lookup("Stuff"));
        Assert.assertEquals("Stuff", reg.lookup("stuff"));
        Assert.assertEquals(null, reg.lookup("miss"));
        Assert.assertEquals(null, reg.lookup(null));
    }

}

==> httpcomponents-core-5.3.3-src.tar.gz: httpcore5/src/test/java/org/apache/hc/core5/http/config/TestRegistry.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.hc.core5.http.config;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

class TestRegistry {

    @Test
    void testCompleted() {
        final Registry<String> reg = RegistryBuilder.<String>create().register("Stuff", "Stuff").build();
        Assertions.assertEquals("Stuff", reg.lookup("Stuff"));
        Assertions.assertEquals("Stuff", reg.lookup("stuff"));
        Assertions.assertNull(reg.lookup("miss"));
        Assertions.assertNull(reg.lookup(null));
    }

}
